@@ -280,12 +280,11 @@ _gst_debug_init (void)
       GST_DEBUG_BOLD, NULL);
   /* FIXME: fold back to GST_CAT_EVENT in 0.9 */
   GST_CAT_SEEK = _gst_debug_category_new ("GST_SEEK",
-      GST_DEBUG_BOLD | GST_DEBUG_FG_BLUE,
-      "plugins reacting to seek events");
+      GST_DEBUG_BOLD | GST_DEBUG_FG_BLUE, "plugins reacting to seek events");
   GST_CAT_SIGNAL = _gst_debug_category_new ("GST_SIGNAL",
       GST_DEBUG_BOLD | GST_DEBUG_FG_WHITE | GST_DEBUG_BG_RED, NULL);
   GST_CAT_PROBE = _gst_debug_category_new ("GST_PROBE",
-        GST_DEBUG_BOLD | GST_DEBUG_FG_GREEN, "pad probes");
+      GST_DEBUG_BOLD | GST_DEBUG_FG_GREEN, "pad probes");
 
 
   /* print out the valgrind message if we're in valgrind */
@@ -518,7 +517,7 @@ gst_debug_log_default (GstDebugCategory * category, GstDebugLevel level,
 
   g_get_current_time (&now);
   g_printerr ("%s (%p - %" GST_TIME_FORMAT
-      ") %s%15s%s(%s%5d%s) %s%s(%d):%s:%s%s %s\n",
+      ") %s%20s%s(%s%5d%s) %s%s(%d):%s:%s%s %s\n",
       gst_debug_level_get_name (level), g_thread_self (),
       GST_TIME_ARGS (GST_TIMEVAL_TO_TIME (now)), color,
       gst_debug_category_get_name (category), clear, pidcolor, pid, clear,
@@ -1039,7 +1038,9 @@ gst_debug_get_all_categories (void)
 
 /*** FUNCTION POINTERS ********************************************************/
 
-GHashTable *__gst_function_pointers = NULL;
+static GHashTable *__gst_function_pointers;     /* NULL */
+static GStaticMutex __dbg_functions_mutex = G_STATIC_MUTEX_INIT;
+
 const gchar *
 _gst_debug_nameof_funcptr (void *ptr)
     G_GNUC_NO_INSTRUMENT;
@@ -1053,9 +1054,12 @@ _gst_debug_nameof_funcptr (void *ptr)
   Dl_info dlinfo;
 #endif
 
-  if (__gst_function_pointers
-      && (ptrname = g_hash_table_lookup (__gst_function_pointers, ptr))) {
-    return ptrname;
+  if (__gst_function_pointers) {
+    g_static_mutex_lock (&__dbg_functions_mutex);
+    ptrname = g_hash_table_lookup (__gst_function_pointers, ptr);
+    g_static_mutex_unlock (&__dbg_functions_mutex);
+    if (ptrname)
+      return ptrname;
   }
   /* we need to create an entry in the hash table for this one so we don't leak
    * the name */
@@ -1078,11 +1082,15 @@ _gst_debug_nameof_funcptr (void *ptr)
 void *
 _gst_debug_register_funcptr (void *ptr, gchar * ptrname)
 {
+  g_static_mutex_lock (&__dbg_functions_mutex);
+
   if (!__gst_function_pointers)
     __gst_function_pointers = g_hash_table_new (g_direct_hash, g_direct_equal);
   if (!g_hash_table_lookup (__gst_function_pointers, ptr))
     g_hash_table_insert (__gst_function_pointers, ptr, ptrname);
 
+  g_static_mutex_unlock (&__dbg_functions_mutex);
+
   return ptr;
 }
 
@@ -1117,6 +1125,17 @@ _gst_info_printf_extension_arginfo (const struct printf_info *info, size_t n,
 #endif /* HAVE_PRINTF_EXTENSION */
 
 #else /* !GST_DISABLE_GST_DEBUG */
+guint
+gst_debug_remove_log_function (GstLogFunction func)
+{
+  return 0;
+}
+
+guint
+gst_debug_remove_log_function_by_data (gpointer data)
+{
+  return 0;
+}
 
 gboolean
 __gst_in_valgrind (void)
