@@ -25,6 +25,7 @@
 
 #include "gst_private.h"
 #include "gst-i18n-lib.h"
+#include "gstbuffer.h"
 #include "gsttag.h"
 #include "gstinfo.h"
 #include "gstvalue.h"
@@ -188,6 +189,11 @@ _gst_tag_initialize (void)
       G_TYPE_DOUBLE, _("replaygain album gain"), _("album gain in db"), NULL);
   gst_tag_register (GST_TAG_ALBUM_PEAK, GST_TAG_FLAG_META,
       G_TYPE_DOUBLE, _("replaygain album peak"), _("peak of the album"), NULL);
+  gst_tag_register (GST_TAG_LANGUAGE_CODE, GST_TAG_FLAG_META, G_TYPE_STRING,
+      _("language code"),
+      _("language code for this stream, conforming to ISO-639-1"), NULL);
+  gst_tag_register (GST_TAG_IMAGE, GST_TAG_FLAG_META, GST_TYPE_BUFFER,
+      _("image"), _("cover art or image for screenshot display"), NULL);
 }
 
 /**
@@ -277,7 +283,11 @@ gst_tag_register (const gchar * name, GstTagFlag flag, GType type,
 
   key = g_quark_from_string (name);
   info = gst_tag_lookup (key);
-  g_return_if_fail (info == NULL);
+
+  if (info) {
+    g_return_if_fail (info->type == type);
+    return;
+  }
 
   info = g_new (GstTagInfo, 1);
   info->flag = flag;
